<?php

/**
 * @file
 * Contains module theme implementations.
 */

/**
 * Main menu theme function.
 */
function theme_rwd_menu($variables) {
  if (empty($variables['source'])) {
    $variables['source'] = variable_get('rwd_menu_links_source', 'main-menu');
  }
  $menu_tree = menu_tree_all_data($variables['source']);
  if (!empty($menu_tree)) {
    $type = $variables['type'];
    if (empty($type)) {
      $type = 'slide';
    }
    $callable = '_rwd_menu_theme_' . $type;
    if (is_callable($callable)) {
      return $callable($menu_tree);
    }
  }
  return '';
}

/**
 * Slide type menu theme function.
 */
function _rwd_menu_theme_slide($menu_tree, $include_trigger = TRUE, $level = 0, $parent = NULL) {
  drupal_add_js(drupal_get_path('module', 'rwd_menu') . '/rwd_menu.js');
  drupal_add_css(drupal_get_path('module', 'rwd_menu') . '/rwd_menu.css');
  $menu = '';

  $number = 0;
  $nelements = count($menu_tree);
  $menu_items = '';
  foreach ($menu_tree as $key => $element) {
    if ($element['link']['hidden'] !== '0') {
      continue;
    }
    $number++;
    $below = !empty($element['below']);
    if ($below) {
      $submenu = _rwd_menu_theme_slide($element['below'], FALSE, ($level + 1), $element);
    }
    if (empty($submenu)) {
      $below = FALSE;
    }

    $element_classes = array();
    if ($number === 1) {
      $element_classes[] = 'first';
    }
    if ($number === $nelements) {
      $element_classes[] = 'last';
    }
    if ($number % 2 === 0) {
      $element_classes[] = 'even';
    }
    else {
      $element_classes[] = 'odd';
    }
    $element_classes[] = 'mlid-' . $element['link']['mlid'];
    if ($below) {
      $element_classes[] = 'branch';
    }
    else {
      $element_classes[] = 'leaf';
    }

    $menu_items .= '<li class="' . implode(' ', $element_classes) . '"><a href="' . url($element['link']['href']) . '">' . $element['link']['title'] . '</a>';
    if ($below) {
      $menu_items .= $submenu;
    }
    $menu_items .= '</li>';
  }

  if ($menu_items) {
    if ($level === 0) {
      if ($include_trigger) {
        $menu .= '<a class="rwd-menu-trigger open" href="javascript:void(0);">' . t('Menu') . '</a>';
      }
      $menu .= '<div class="rwd-menu slide"><nav><a href="javascript:void(0)" class="rwd-menu-trigger close">' . t('Close') . '</a>';
    }

    $menu_classes = array('menu');
    if ($level > 0) {
      $menu_classes[] = 'submenu';
    }
    $menu_classes[] = 'level-' . $level;
    $menu .= '<div class="' . implode(' ', $menu_classes) . '">';

    if ($level > 0) {
      if (!empty($parent['link']['href'])) {
        $title = '<a href="' . url($parent['link']['href']) . '">' . $parent['link']['title'] . '</a>';
      }
      else {
        $title = $parent['link']['title'];
      }
      $menu .= '<div class="top"><a href="javascript:void(0)" class="back">' . t('Back') . '</a><span class="title">' . $title . '</span></div>';
    }

    $menu .= '<ul>' . $menu_items . '</ul>';
    if ($level === 0) {
      $menu .= '</nav></div>';
    }
  }
  return $menu;
}
